@@ -6,6 +6,7 @@ import tempfile
 import shlex
 import shutil
 import sys
+import atexit
 from subprocess import Popen, PIPE
 from requests import ConnectionError
 
@@ -29,7 +30,7 @@ logger = logging.getLogger(__name__)
 
 class InsightsClient(object):
 
-    def __init__(self, config=None, setup_logging=True, **kwargs):
+    def __init__(self, config=None, from_phase=True, **kwargs):
         """
         The Insights client interface
         """
@@ -49,22 +50,19 @@ class InsightsClient(object):
                     sys.exit(constants.sig_kill_bad)
             # END hack. in the future, just set self.config=config
 
-        # setup_logging is True when called from phase, but not from wrapper.
-        #  use this to do any common init (like auto_config)
-        if setup_logging:
+        if from_phase:
             _init_client_config_dirs()
             self.set_up_logging()
             try_auto_configuration(self.config)
             self.initialize_tags()
-        else:
-            # write PID to file in case we need to ping systemd
-            write_to_disk(constants.pidfile, content=str(os.getpid()))
-            # write PPID to file so that we can grab the client execution method
-            write_to_disk(constants.ppidfile, content=get_parent_process())
+        else:  # from wrapper
+            _write_pid_files()
+
         # setup insights connection placeholder
         # used for requests
         self.session = None
         self.connection = None
+        self.tmpdir = None
 
     def _net(func):
         def _init_connection(self, *args, **kwargs):
@@ -121,10 +119,11 @@ class InsightsClient(object):
             returns (dict): {'core': path to new egg, None if no update,
                              'gpg_sig': path to new sig, None if no update}
         """
-        tmpdir = tempfile.mkdtemp()
+        self.tmpdir = tempfile.mkdtemp()
+        atexit.register(self.delete_tmpdir)
         fetch_results = {
-            'core': os.path.join(tmpdir, 'insights-core.egg'),
-            'gpg_sig': os.path.join(tmpdir, 'insights-core.egg.asc')
+            'core': os.path.join(self.tmpdir, 'insights-core.egg'),
+            'gpg_sig': os.path.join(self.tmpdir, 'insights-core.egg.asc')
         }
 
         logger.debug("Beginning core fetch.")
@@ -372,6 +371,11 @@ class InsightsClient(object):
         logger.debug("The new Insights Core was installed successfully.")
         return {'success': True}
 
+    def delete_tmpdir(self):
+        if self.tmpdir:
+            logger.debug("Deleting temp directory %s." % (self.tmpdir))
+            shutil.rmtree(self.tmpdir, True)
+
     @_net
     def update_rules(self):
         """
@@ -710,3 +714,12 @@ def _init_client_config_dirs():
                 pass
             else:
                 raise e
+
+
+def _write_pid_files():
+    for file, content in (
+        (constants.pidfile, str(os.getpid())),  # PID in case we need to ping systemd
+        (constants.ppidfile, get_parent_process())  # PPID so that we can grab the client execution method
+    ):
+        write_to_disk(file, content=content)
+        atexit.register(write_to_disk, file, delete=True)
