@@ -103,6 +103,42 @@ plugins:
         - name: insights.combiners.hostname
           enabled: true
 
+    # needed for the CloudProvider combiner
+        - name: insights.parsers.installed_rpms
+          enabled: true
+
+        - name: insights.parsers.dmidecode
+          enabled: true
+
+        - name: insights.parsers.yum
+          enabled: true
+
+        - name: insights.parsers.rhsm_conf
+          enabled: true
+
+        - name: insights.combiners.cloud_provider
+          enabled: true
+
+    # needed for the Services combiner
+        - name: insights.parsers.chkconfig
+          enabled: true
+
+        - name: insights.parsers.systemd.unitfiles
+          enabled: true
+
+        - name: insights.combiners.services
+          enabled: true
+
+    # needed to collect the sap_hdb_version spec that uses the Sap combiner
+        - name: insights.parsers.lssap
+          enabled: true
+
+        - name: insights.parsers.saphostctrl
+          enabled: true
+
+        - name: insights.combiners.sap
+          enabled: true
+
     # needed because some specs aren't given names before they're used in DefaultSpecs
         - name: insights.core.spec_factory
           enabled: true
