@@ -16,6 +16,7 @@ class Openshift(SpecSet):
 
 
 class Specs(SpecSet):
+    abrt_ccpp_conf = RegistryPoint(filterable=True)
     abrt_status_bare = RegistryPoint()
     amq_broker = RegistryPoint(multi_output=True)
     auditctl_status = RegistryPoint()
@@ -34,7 +35,7 @@ class Specs(SpecSet):
     bond = RegistryPoint(multi_output=True)
     bond_dynamic_lb = RegistryPoint(multi_output=True)
     boot_loader_entries = RegistryPoint(multi_output=True)
-    branch_info = RegistryPoint()
+    branch_info = RegistryPoint(raw=True)
     brctl_show = RegistryPoint()
     candlepin_error_log = RegistryPoint(filterable=True)
     candlepin_log = RegistryPoint(filterable=True)
@@ -140,6 +141,8 @@ class Specs(SpecSet):
     docker_storage = RegistryPoint()
     docker_storage_setup = RegistryPoint()
     docker_sysconfig = RegistryPoint()
+    dotnet_version = RegistryPoint()
+    doveconf = RegistryPoint(filterable=True)
     dracut_kdump_capture_service = RegistryPoint()
     du_dirs = RegistryPoint(multi_output=True)
     dumpe2fs_h = RegistryPoint(multi_output=True)
@@ -149,6 +152,7 @@ class Specs(SpecSet):
     etc_journald_conf_d = RegistryPoint(multi_output=True)
     etc_journald_conf = RegistryPoint()
     etc_machine_id = RegistryPoint()
+    etc_udev_40_redhat_rules = RegistryPoint(filterable=True)
     etcd_conf = RegistryPoint(filterable=True)
     ethernet_interfaces = RegistryPoint()
     ethtool_a = RegistryPoint(multi_output=True)
@@ -372,6 +376,7 @@ class Specs(SpecSet):
     netstat_i = RegistryPoint()
     netstat = RegistryPoint()
     netstat_s = RegistryPoint()
+    networkmanager_conf = RegistryPoint()
     networkmanager_dispatcher_d = RegistryPoint(multi_output=True)
     neutron_conf = RegistryPoint(filterable=True)
     neutron_sriov_agent = RegistryPoint(filterable=True)
@@ -465,11 +470,14 @@ class Specs(SpecSet):
     pcs_config = RegistryPoint()
     pcs_quorum_status = RegistryPoint()
     pcs_status = RegistryPoint()
+    php_ini = RegistryPoint(filterable=True)
     pluginconf_d = RegistryPoint(multi_output=True)
     podman_container_inspect = RegistryPoint(multi_output=True)
     podman_image_inspect = RegistryPoint(multi_output=True)
     podman_list_containers = RegistryPoint()
     podman_list_images = RegistryPoint()
+    postconf_builtin = RegistryPoint(filterable=True)
+    postconf = RegistryPoint(filterable=True)
     postgresql_conf = RegistryPoint()
     postgresql_log = RegistryPoint(multi_output=True, filterable=True)
     prev_uploader_log = RegistryPoint()
@@ -532,7 +540,7 @@ class Specs(SpecSet):
     root_crontab = RegistryPoint()
     route = RegistryPoint()
     rpm_V_packages = RegistryPoint()
-    rsyslog_conf = RegistryPoint(filterable=True)
+    rsyslog_conf = RegistryPoint(filterable=True, multi_output=True)
     samba = RegistryPoint(filterable=True)
     sap_dev_disp = RegistryPoint(multi_output=True, filterable=True)
     sap_dev_rd = RegistryPoint(multi_output=True, filterable=True)
@@ -627,6 +635,8 @@ class Specs(SpecSet):
     systemd_system_origin_accounting = RegistryPoint()
     systemid = RegistryPoint()
     systool_b_scsi_v = RegistryPoint()
+    testparm_s = RegistryPoint(filterable=True)
+    testparm_v_s = RegistryPoint(filterable=True)
     tags = RegistryPoint()
     teamdctl_config_dump = RegistryPoint(multi_output=True)
     teamdctl_state_dump = RegistryPoint(multi_output=True)
@@ -659,6 +669,7 @@ class Specs(SpecSet):
     vgs_noheadings = RegistryPoint()
     vgs_noheadings_all = RegistryPoint()
     vgs = RegistryPoint()
+    vhost_net_zero_copy_tx = RegistryPoint()
     virsh_list_all = RegistryPoint()
     virt_what = RegistryPoint()
     virt_who_conf = RegistryPoint(multi_output=True, filterable=True)
