@@ -32,9 +32,9 @@ class InsightsArchiveSpecs(Specs):
     cpupower_frequency_info = simple_file("insights_commands/cpupower_-c_all_frequency-info")
     date = simple_file("insights_commands/date")
     date_utc = simple_file("insights_commands/date_--utc")
-    df__al = simple_file("insights_commands/df_-al")
-    df__alP = simple_file("insights_commands/df_-alP")
-    df__li = simple_file("insights_commands/df_-li")
+    df__al = first_file(["insights_commands/df_-al_-x_autofs", "insights_commands/df_-al"])
+    df__alP = first_file(["insights_commands/df_-alP_-x_autofs", "insights_commands/df_-alP"])
+    df__li = first_file(["insights_commands/df_-li_-x_autofs", "insights_commands/df_-li"])
     dig_dnssec = simple_file("insights_commands/dig_dnssec_._SOA")
     dig_edns = simple_file("insights_commands/dig_edns_0_._SOA")
     dig_noedns = simple_file("insights_commands/dig_noedns_._SOA")
@@ -45,6 +45,8 @@ class InsightsArchiveSpecs(Specs):
     docker_info = simple_file("insights_commands/docker_info")
     docker_list_containers = simple_file("insights_commands/docker_ps_--all_--no-trunc")
     docker_list_images = simple_file("insights_commands/docker_images_--all_--no-trunc_--digests")
+    dotnet_version = simple_file("insights_commands/dotnet_--version")
+    doveconf = simple_file("insights_commands/doveconf")
     du_dirs = glob_file("insights_commands/du_-s_-k_*")
     engine_db_query_vdsm_version = simple_file("insights_commands/engine-db-query_--statement_SELECT_vs.vds_name_rpm_version_FROM_vds_dynamic_vd_vds_static_vs_WHERE_vd.vds_id_vs.vds_id_--json")
     ethtool = glob_file("insights_commands/ethtool_*", ignore="ethtool_-.*")
@@ -173,6 +175,8 @@ class InsightsArchiveSpecs(Specs):
     pcp_metrics = simple_file("insights_commands/curl_-s_http_..127.0.0.1_44322.metrics_--connect-timeout_5")
     pcs_quorum_status = simple_file("insights_commands/pcs_quorum_status")
     pcs_status = simple_file("insights_commands/pcs_status")
+    postconf_builtin = simple_file("insights_commands/postconf_-C_builtin")
+    postconf = simple_file("insights_commands/postconf")
     ps_alxwww = simple_file("insights_commands/ps_alxwww")
     ps_aux = simple_file("insights_commands/ps_aux")
     ps_auxcww = simple_file("insights_commands/ps_auxcww")
@@ -190,8 +194,7 @@ class InsightsArchiveSpecs(Specs):
     rhev_data_center = simple_file("insights_commands/python_-m_insights.tools.cat_--no-header_rhev_data_center")
     rndc_status = simple_file("insights_commands/rndc_status")
     rpm_V_packages = first_file(["insights_commands/rpm_-V_coreutils_procps_procps-ng_shadow-utils_passwd_sudo_chrony", "insights_commands/rpm_-V_coreutils_procps_procps-ng_shadow-utils_passwd_sudo"])
-    sap_dev_disp = glob_file("/usr/sap/*/*/work/dev_disp")
-    sap_dev_rd = glob_file("/usr/sap/*/*/work/dev_rd")
+    sap_hdb_version = simple_file("insights_commands/python_-m_insights.tools.cat_--no-header_sap_hdb_version")
     saphostctl_getcimobject_sapinstance = simple_file("insights_commands/usr.sap.hostctrl.exe.saphostctrl_-function_GetCIMObject_-enuminstances_SAPInstance")
     satellite_mongodb_storage_engine = simple_file("insights_commands/mongo_pulp_database_--eval_db.serverStatus_.storageEngine")
     sealert = simple_file('insights_commands/sealert_-l')
@@ -219,6 +222,8 @@ class InsightsArchiveSpecs(Specs):
     systemd_docker = first_file(["insights_commands/systemctl_cat_docker.service", "/usr/lib/systemd/system/docker.service"])
     systemd_openshift_node = first_file(["insights_commands/systemctl_cat_atomic-openshift-node.service", "/usr/lib/systemd/system/atomic-openshift-node.service"])
     systool_b_scsi_v = simple_file("insights_commands/systool_-b_scsi_-v")
+    testparm_s = simple_file("insights_commands/testparm_-s")
+    testparm_v_s = simple_file("insights_commands/testparm_-v_-s")
     tomcat_vdc_fallback = simple_file("insights_commands/find_.usr.share_-maxdepth_1_-name_tomcat_-exec_.bin.grep_-R_-s_VirtualDirContext_--include_.xml")
     tuned_adm = simple_file("insights_commands/tuned-adm_list")
     uname = simple_file("insights_commands/uname_-a")
